@@ -1,5 +1,5 @@
 ## util_color.R  |  unikn
-## spds | uni.kn | 2022 12 30
+## spds | uni.kn | 2023 06 06
 ## ---------------------------
 
 # Color-related utility functions: 
@@ -137,6 +137,43 @@ is_col <- function(color) {
 # is_col(col2rgb("white"))  # => FALSE FALSE FALSE
 
 
+
+# - is_col_pal(): Verify an existing color palette ------ 
+
+is_col_pal <- function(x) {
+  
+  # if ( !typeof(x) %in% c("vector", "list") ) {  # BUG: uni-pals are of type "character"!
+  if ( !is.vector(x) & !is.list(x) ) { # most palettes are vectors or lists:
+    
+    is_color_ix <- FALSE
+    
+    # ToDo: usecol() returns an object for which attr(cols, which = "comment") == "custom"
+    #       => is.vector() is FALSE for such objects!
+    
+  } else { # verify that all elements of x:
+    
+    # is_color_ix <- is_hex_col(color = x)  # Why only check for HEX colors?
+    is_color_ix <- is_col(color = x)
+    
+  }
+  
+  return(all(is_color_ix))  # TRUE iff ALL elements are colors
+  
+} # is_col_pal(). 
+
+## Check: 
+# # TRUE for 
+# is_col_pal(c("black", "grey", "white"))
+# is_col_pal(pal_unikn)
+# is_col_pal(uni_freiburg_br)
+# is_col_pal(newpal(col = c("black", "white"), as_df = FALSE))
+# is_col_pal(RColorBrewer::brewer.pal(n = 5, name = "Set2"))
+# # but FALSE for palettes modified by usecol():
+# is_col_pal(usecol(c("black", "white"), n = 3))
+# is_col_pal(usecol(pal_unikn, n = 3))
+
+
+
 # - col_asif_alpha(): Color corresponding to the hue of a transparent color ------ 
 
 # Which non-transparent color values match the hue of a transparent color?
@@ -714,29 +751,10 @@ get_pal_key <- function(pal = "all", n = "all", alpha = NA) {
   lst_pal <- sapply(pal_names, get)
   # print(lst_pal)  # 4debugging
   
-  # Check which lst_pal elements are actually color palettes:
+  # Check which lst_pal elements are pre-existing color palettes:
   is_pal <- lapply(X = lst_pal,
-                   FUN = function(x) {
-                     
-                     # if ( !typeof(x) %in% c("vector", "list") ) {  # BUG: uni-pals are of type "character"!
-                     if ( !is.vector(x) & !is.list(x) ) { # palettes are vectors or lists:
-                       
-                       is_color_ix <- FALSE
-                       
-                       # ToDo: usecol() returns an object for which attr(cols, which = "comment") == "custom"
-                       #       => is.vector() is FALSE for such objects!
-                       
-                     } else { # check all elements:
-                       
-                       # is_color_ix <- is_hex_col(color = x)  # Why only check for HEX colors?
-                       is_color_ix <- is_col(color = x)
-                       
-                     }
-                     
-                     return(all(is_color_ix))  # TRUE iff ALL elements are colors
-                     
-                   }
-  ) # ToDo: Define FUN as a separate function is_col_pal().
+                   FUN = is_col_pal)  # using utility function (see above)
+  # Note: Palettes modified by usecol() are NOT pre-existing color palettes.
   
   # print(is_pal)  # 4debugging
   
@@ -776,10 +794,25 @@ get_pal_key <- function(pal = "all", n = "all", alpha = NA) {
 } # get_pal_key(). 
 
 
+
 # - get_col_names(): Get custom and default color names ------
 
+#' Get color names
+#'
+#' \code{get_col_names} gets color names from color palettes.
+#' 
+#' @param col A vector of colors.
+#' @param custom_pals A vector of color palettes.
+#' 
+#' @return A vector of color names.
+#' 
+#' @family utility functions
+
 get_col_names <- function(col, custom_pals = all_pals){
   
+  # 0. Prepare:
+  require(unikn, quietly = TRUE)  # ensure that unikn is attached (when calling from other pkgs)
+  
   # 1. Customized names from custom color palettes:
   cus_pals  <- lapply(X = custom_pals, FUN = get)
   cus_names <- names(unlist(cus_pals))[match(col, unlist(cus_pals))]
